==> apache-cxf-3.6.9-src.zip: apache-cxf-3.6.9-src/core/src/main/java/org/apache/cxf/attachment/DelegatingInputStream.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.attachment;


import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.apache.cxf.helpers.IOUtils;
import org.apache.cxf.io.Transferable;

public class DelegatingInputStream extends InputStream implements Transferable {
    private InputStream is;
    private AttachmentDeserializer deserializer;
    private boolean isClosed;

    DelegatingInputStream(InputStream is, AttachmentDeserializer ads) {
        this.is = is;
        deserializer = ads;
    }
    DelegatingInputStream(InputStream is) {
        this.is = is;
        deserializer = null;
    }

    @Override
    public void close() throws IOException {
        IOUtils.consume(is);
        is.close();
        if (!isClosed && deserializer != null) {
            deserializer.markClosed(this);
        }
        isClosed = true;
    }

    public void transferTo(File destinationFile) throws IOException {
        if (isClosed) {
            throw new IOException("Stream is closed");
        }
        IOUtils.transferTo(is, destinationFile);
    }

    public boolean isClosed() {
        return isClosed;
    }

    public void setClosed(boolean closed) {
        this.isClosed = closed;
    }

    public int read() throws IOException {
        return this.is.read();
    }

    @Override
    public int available() throws IOException {
        return this.is.available();
    }

    @Override
    public synchronized void mark(int arg0) {
        this.is.mark(arg0);
    }

    @Override
    public boolean markSupported() {
        return this.is.markSupported();
    }

    @Override
    public int read(byte[] bytes, int arg1, int arg2) throws IOException {
        return this.is.read(bytes, arg1, arg2);
    }

    @Override
    public int read(byte[] bytes) throws IOException {
        return this.is.read(bytes);
    }

    @Override
    public synchronized void reset() throws IOException {
        this.is.reset();
    }

    @Override
    public long skip(long n) throws IOException {
        return this.is.skip(n);
    }

    public void setInputStream(InputStream inputStream) {
        this.is = inputStream;
    }


    public InputStream getInputStream() {
        return is;
    }
}

==> apache-cxf-4.1.4-src.zip: apache-cxf-4.1.4-src/core/src/main/java/org/apache/cxf/attachment/DelegatingInputStream.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.attachment;


import java.io.File;
import java.io.IOException;
import java.io.InputStream;

import org.apache.cxf.helpers.IOUtils;
import org.apache.cxf.io.Transferable;

public class DelegatingInputStream extends InputStream implements Transferable {
    private InputStream is;
    private CloseableAttachmentDeserializer deserializer;
    private boolean isClosed;

    DelegatingInputStream(InputStream is, AttachmentDeserializer ads) {
        this(is, ads::markClosed);
    }

    DelegatingInputStream(InputStream is, CloseableAttachmentDeserializer ads) {
        this.is = is;
        deserializer = ads;
    }

    DelegatingInputStream(InputStream is) {
        this.is = is;
        deserializer = null;
    }

    @Override
    public void close() throws IOException {
        IOUtils.consume(is);
        is.close();
        if (!isClosed && deserializer != null) {
            deserializer.markClosed(this);
        }
        isClosed = true;
    }

    public void transferTo(File destinationFile) throws IOException {
        if (isClosed) {
            throw new IOException("Stream is closed");
        }
        IOUtils.transferTo(is, destinationFile);
    }

    public boolean isClosed() {
        return isClosed;
    }

    public void setClosed(boolean closed) {
        this.isClosed = closed;
    }

    public int read() throws IOException {
        return this.is.read();
    }

    @Override
    public int available() throws IOException {
        return this.is.available();
    }

    @Override
    public synchronized void mark(int arg0) {
        this.is.mark(arg0);
    }

    @Override
    public boolean markSupported() {
        return this.is.markSupported();
    }

    @Override
    public int read(byte[] bytes, int arg1, int arg2) throws IOException {
        return this.is.read(bytes, arg1, arg2);
    }

    @Override
    public int read(byte[] bytes) throws IOException {
        return this.is.read(bytes);
    }

    @Override
    public synchronized void reset() throws IOException {
        this.is.reset();
    }

    @Override
    public long skip(long n) throws IOException {
        return this.is.skip(n);
    }

    public void setInputStream(InputStream inputStream) {
        this.is = inputStream;
    }


    public InputStream getInputStream() {
        return is;
    }
}
